/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xfancy.c                                                      *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : fancy routines                                           *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * Functions    : XMdcMakeMyCursors()     - Make my prefered cursors       *
 *                XMdcFreeMyStuff()       - Free my prefered stuff         *
 *                XMdcAbout()             - Hello                          *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*
 */

/*
   Copyright (C) 1997-2021 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

/****************************************************************************
                              H E A D E R S
****************************************************************************/

#include "m-depend.h"

#include <stdio.h>
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#ifdef HAVE_STRINGS_H
#ifndef _WIN32
#include <strings.h>
#endif
#endif

#include "xmedcon.h"

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void XMdcMakeMyCursors(void)
{
  handcursor  = gdk_cursor_new(GDK_HAND2);
  fleurcursor = gdk_cursor_new(GDK_FLEUR);

  if (handcursor == NULL || fleurcursor == NULL)
    XMdcDisplayErr("Couldn't get cursor types");

}

void XMdcFreeMyStuff(void)
{
  /* the cursors */
  if (handcursor != NULL) gdk_cursor_unref(handcursor);
  if (fleurcursor != NULL) gdk_cursor_unref(fleurcursor);
}

void XMdcAbout(GtkWidget *widget, gpointer data)
{
  GtkWidget *window=NULL;
  GtkWidget *box1;
  GtkWidget *label;
  GtkWidget *button;

  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  g_signal_connect(GTK_OBJECT(window),"destroy",
                     G_CALLBACK(gtk_widget_destroy),NULL);
  gtk_window_set_title(GTK_WINDOW(window),"Hello There");

  gtk_container_set_border_width(GTK_CONTAINER(window), 0);

  box1 = gtk_vbox_new (FALSE, 0);
  gtk_container_add(GTK_CONTAINER(window),box1);
  gtk_widget_show(box1);

  sprintf(mdcbufr," %s \n\n",MdcGetLibLongVersion());
  strcat(mdcbufr," http://xmedcon.sourceforge.net \n\n" \
                 " With special regards to You \n\n" \
                 " Licensed  by  Murphy's Law \n" \
                 " Enjoy it ...");
  label = gtk_label_new(mdcbufr);
  gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_CENTER);
  gtk_box_pack_start(GTK_BOX(box1),label,TRUE,TRUE,5);
  gtk_widget_show(label);

  button = gtk_button_new_with_label("Bye");
  g_signal_connect_swapped(GTK_OBJECT(button),"clicked",
                     G_CALLBACK(gtk_widget_destroy),
                     GTK_OBJECT(window));
  gtk_box_pack_start(GTK_BOX(box1),button,TRUE,TRUE,5);
  gtk_widget_show(button);

  XMdcShowWidget(window);

}

